Learn R Programming

pubmedR (version 1.0.2)

pmCitedBy: Find articles that cite a given PubMed article

Description

It retrieves the PMIDs of articles that cite a given PubMed article, using the NCBI E-Link service (PubMed Cited by).

Usage

pmCitedBy(pmid, api_key = NULL)

Value

a list containing:

pmidThe queried PMID.
cited_byA character vector of PMIDs that cite the queried article.
countThe number of citing articles found.

Arguments

pmid

is a character or numeric. A single PubMed identifier (PMID).

api_key

is a character. It contains a valid API key for the NCBI E-utilities. Default is api_key=NULL. The API key can also be set via the environment variable PUBMED_API_KEY or ENTREZ_KEY.

Details

This function uses the NCBI E-Link endpoint with linkname "pubmed_pubmed_citedin" to find articles in PubMed that cite the given article.

Note: Citation data in PubMed is based on PubMed Central (PMC) and may not be as comprehensive as commercial citation databases (e.g. Web of Science, Scopus).

See Also

pmReferences

pmFetchById

Examples

Run this code

# \donttest{
# Find articles that cite PMID 25824007
cites <- pmCitedBy(pmid = "25824007")
cites$count
cites$cited_by
# }

Run the code above in your browser using DataLab