pmApiRequest: Gather bibliographic content from PubMed database using NCBI entrez APIs
Description
It gathers metadata about publications from the NCBI PubMed database.
The use of NCBI PubMed APIs is entirely free, and doesn't necessarily require an API key.
The function pmApiRequest queries NCBI PubMed using an entrez query formulated through
the Entrez query language or the helper function pmQueryBuild.
is a character. It contains a search query formulated using the Entrez query language.
limit
is numeric. It indicates the max number of records to download.
api_key
is a character. It contains a valid API key for the NCBI E-utilities.
Default is api_key=NULL. The API key can also be set via the environment variable
PUBMED_API_KEY or ENTREZ_KEY.
batch_size
is numeric. The number of records to download per API request. Default is 200.