is a character. It contains a search query formulated using the Entrez query language.
api_key
is a character. It contains a valid API key for the NCBI E-utilities. Default is api_key=NULL.
The use of NCBI PubMed APIs is entirely free, and doesn't necessarily require an API key.
The API key can also be set via the environment variable PUBMED_API_KEY or ENTREZ_KEY.