pmReferences: Find references cited by a given PubMed article
Description
It retrieves the PMIDs of articles that are cited by (referenced in) a given
PubMed article, using the NCBI E-Link service.
Usage
pmReferences(pmid, api_key = NULL)
Value
a list containing:
pmid
The queried PMID.
references
A character vector of PMIDs referenced by the queried article.
count
The number of references found.
Arguments
pmid
is a character or numeric. A single PubMed identifier (PMID).
api_key
is a character. It contains a valid API key for the NCBI E-utilities.
Default is api_key=NULL. The API key can also be set via the environment variable
PUBMED_API_KEY or ENTREZ_KEY.
Details
This function uses the NCBI E-Link endpoint with linkname "pubmed_pubmed_refs"
to find articles in PubMed that are referenced by the given article.
Note: Reference data is extracted from PubMed Central (PMC) full-text articles and
is only available when the full text is deposited in PMC. Not all PubMed articles
have reference data available.